@@ -5,7 +5,7 @@
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 subroutine bfsp_no (weights, zcv, logbf, lglk1, lglk2, &
-   philist, nsqlist, nulist, &
+   philist, omglist, nulist, &
    zsample1, Nout1, Ntot1, zsample2, Nout2, Ntot2, &
    y, l, F, dm, betm0, betQ0, ssqdf, ssqsc, tsqdf, tsq, &
    kappalist, icf, n, p, kg, ifam, imeth, itr)
@@ -20,7 +20,7 @@ subroutine bfsp_no (weights, zcv, logbf, lglk1, lglk2, &
   implicit none
   integer, intent(in) :: n, p, kg, ifam, imeth, Nout1(kg), Ntot1, &
      Nout2(kg), Ntot2, icf, itr(n)
-  double precision, intent(in) :: philist(kg), nsqlist(kg), nulist(kg), &
+  double precision, intent(in) :: philist(kg), omglist(kg), nulist(kg), &
      zsample1(n,Ntot1), zsample2(n,Ntot2), y(n), l(n), F(n, p), &
      dm(n,n), betm0(p), betQ0(p,p), ssqdf, ssqsc, tsqdf, tsq, kappalist(kg)
   double precision, intent(out) :: logbf(kg), lglk1(Ntot1,kg), &
@@ -46,7 +46,7 @@ subroutine bfsp_no (weights, zcv, logbf, lglk1, lglk2, &
   case (0)
     do i = 1, kg
       nu = nulist(i)
-      call calc_cov (philist(i),nsqlist(i),dm,F,betQ0,&
+      call calc_cov (philist(i),omglist(i),dm,F,betQ0,&
          kappalist(i),n,p,T,TiF,FTF,Ups,ldh_Ups)
       do j = 1, Ntot1
         call rchkusr
@@ -62,7 +62,7 @@ subroutine bfsp_no (weights, zcv, logbf, lglk1, lglk2, &
   case default
     do i = 1, kg
       nu = nulist(i)
-      call calc_cov (philist(i),nsqlist(i),dm,F,betQ0,&
+      call calc_cov (philist(i),omglist(i),dm,F,betQ0,&
          kappalist(i),n,p,T,TiF,FTF,Ups,ldh_Ups)
       do j = 1, Ntot1
         call rchkusr
@@ -125,7 +125,7 @@ end subroutine bfsp_no
 !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
 subroutine bfsp_mu (weights, zcv, logbf, lglk1, lglk2, &
-   philist, nsqlist, nulist, &
+   philist, omglist, nulist, &
    musample1, Nout1, Ntot1, musample2, Nout2, Ntot2, &
    y, l, F, dm, betm0, betQ0, ssqdf, ssqsc, tsqdf, tsq, &
    kappalist, icf, n, p, kg, ifam, imeth, itr)
@@ -140,7 +140,7 @@ subroutine bfsp_mu (weights, zcv, logbf, lglk1, lglk2, &
   implicit none
   integer, intent(in) :: n, p, kg, ifam, imeth, Nout1(kg), Ntot1, &
      Nout2(kg), Ntot2, icf, itr(n)
-  double precision, intent(in) :: philist(kg), nsqlist(kg), nulist(kg), &
+  double precision, intent(in) :: philist(kg), omglist(kg), nulist(kg), &
      musample1(n, Ntot1), musample2(n, Ntot2), y(n), l(n), F(n, p), &
      dm(n, n), betm0(p), betQ0(p, p), ssqdf, ssqsc, tsqdf, tsq, kappalist(kg)
   double precision, intent(out) :: logbf(kg), lglk1(Ntot1, kg), &
@@ -165,7 +165,7 @@ subroutine bfsp_mu (weights, zcv, logbf, lglk1, lglk2, &
   case (0)
     do i = 1, kg
       nu = nulist(i)
-      call calc_cov (philist(i),nsqlist(i),dm,F,betQ0,&
+      call calc_cov (philist(i),omglist(i),dm,F,betQ0,&
          kappalist(i),n,p,T,TiF,FTF,Ups,ldh_Ups)
       do j = 1, Ntot1
         call rchkusr
@@ -181,7 +181,7 @@ subroutine bfsp_mu (weights, zcv, logbf, lglk1, lglk2, &
   case default
     do i = 1, kg
       nu = nulist(i)
-      call calc_cov (philist(i),nsqlist(i),dm,F,betQ0,&
+      call calc_cov (philist(i),omglist(i),dm,F,betQ0,&
          kappalist(i),n,p,T,TiF,FTF,Ups,ldh_Ups)
       do j = 1, Ntot1
         call rchkusr
@@ -203,6 +203,11 @@ subroutine bfsp_mu (weights, zcv, logbf, lglk1, lglk2, &
   eta = log(dble(Nout1))
   select case (imeth)
   case (1)
+!     open(11,file='eta.txt'); write(11,*) eta; close(11)
+!     open(11,file='lglk1.txt'); write(11,*) lglk1; close(11)
+!     open(11,file='kg.txt'); write(11,*) kg; close(11)
+!     open(11,file='Ntot1.txt'); write(11,*) Ntot1; close(11)
+!     open(11,file='Nout1.txt'); write(11,*) Nout1; close(11)
     call revlogistic (eta,lglk1,kg,Ntot1,Nout1)
   case (2)
     call revlogistic (eta,lglk1,kg,Ntot1,Nout1)
@@ -235,7 +240,7 @@ end subroutine bfsp_mu
 
 
 subroutine bfsp_wo (weights, zcv, logbf, lglk1, lglk2, &
-   philist, nsqlist, nulist, &
+   philist, omglist, nulist, &
    sample1, Nout1, Ntot1, sample2, Nout2, Ntot2, &
    y, l, F, dm, betm0, betQ0, ssqdf, ssqsc, tsqdf, tsq, &
    kappalist, icf, n, p, kg, ifam, imeth, itr)
@@ -249,7 +254,7 @@ subroutine bfsp_wo (weights, zcv, logbf, lglk1, lglk2, &
   implicit none
   integer, intent(in) :: n, p, kg, ifam, imeth, Nout1(kg), Ntot1, &
      Nout2(kg), Ntot2, icf, itr(n)
-  double precision, intent(in) :: philist(kg), nsqlist(kg), nulist(kg), &
+  double precision, intent(in) :: philist(kg), omglist(kg), nulist(kg), &
      sample1(n,Ntot1), sample2(n,Ntot2), y(n), l(n), F(n, p), &
      dm(n,n), betm0(p), betQ0(p,p), ssqdf, ssqsc, tsqdf, tsq, kappalist(kg)
   double precision, intent(out) :: logbf(kg), lglk1(Ntot1,kg), &
@@ -260,7 +265,7 @@ subroutine bfsp_wo (weights, zcv, logbf, lglk1, lglk2, &
      xi(n), eta(kg), lglketa(Ntot2, kg)
   integer i, j
   double precision zsam(n), msam(n), jsam(n), sam(n)
-  double precision nu, phi, nsq, kappa
+  double precision nu, phi, omg, kappa
 
   call create_model (ifam)
   call create_spcor(icf,n)
@@ -273,16 +278,16 @@ subroutine bfsp_wo (weights, zcv, logbf, lglk1, lglk2, &
   do i = 1, kg
     nu = nulist(i)
     phi = philist(i)
-    nsq = nsqlist(i)
+    omg = omglist(i)
     kappa = kappalist(i)
-    call calc_cov (phi,nsq,dm,F,betQ0,&
+    call calc_cov (phi,omg,dm,F,betQ0,&
        kappa,n,p,T,TiF,FTF,Ups,ldh_Ups)
     do j = 1, Ntot1
       call rchkusr
       sam = sample1(:,j)
       zsam = transfw(sam,nu)
       msam = invlink(zsam,nu)
-      jsam = logitrwdz(zsam,nu)
+      jsam = loginvtrwdz(zsam,nu)
       lglk1(j,i) = logpdfzf(n,zsam,Ups,ldh_Ups,xi,lmxi,ssqdfsc,modeldfh) &
          + condymuf(n,y,l,msam,tsq) - sum(jsam)
     end do
@@ -291,7 +296,7 @@ subroutine bfsp_wo (weights, zcv, logbf, lglk1, lglk2, &
       sam = sample2(:,j)
       zsam = transfw(sam,nu)
       msam = invlink(zsam,nu)
-      jsam = logitrwdz(zsam,nu)
+      jsam = loginvtrwdz(zsam,nu)
       lglk2(j,i) = logpdfzf(n,zsam,Ups,ldh_Ups,xi,lmxi,ssqdfsc,modeldfh) &
          + condymuf(n,y,l,msam,tsq) - sum(jsam)
     end do
@@ -332,7 +337,7 @@ end subroutine bfsp_wo
 
 
 subroutine bfsp_tr (weights, zcv, logbf, lglk1, lglk2, &
-   philist, nsqlist, nulist, &
+   philist, omglist, nulist, &
    sample1, Nout1, Ntot1, sample2, Nout2, Ntot2, &
    y, l, F, dm, betm0, betQ0, ssqdf, ssqsc, tsqdf, tsq, &
    kappalist, icf, n, p, kg, ifam, imeth, itr)
@@ -347,7 +352,7 @@ subroutine bfsp_tr (weights, zcv, logbf, lglk1, lglk2, &
   implicit none
   integer, intent(in) :: n, p, kg, ifam, imeth, Nout1(kg), Ntot1, &
      Nout2(kg), Ntot2, icf, itr(n)
-  double precision, intent(in) :: philist(kg), nsqlist(kg), nulist(kg), &
+  double precision, intent(in) :: philist(kg), omglist(kg), nulist(kg), &
      sample1(n,Ntot1), sample2(n,Ntot2), y(n), l(n), F(n, p), &
      dm(n,n), betm0(p), betQ0(p,p), ssqdf, ssqsc, tsqdf, tsq, kappalist(kg)
   double precision, intent(out) :: logbf(kg), lglk1(Ntot1,kg), &
@@ -358,7 +363,7 @@ subroutine bfsp_tr (weights, zcv, logbf, lglk1, lglk2, &
      tsqval, respdfh, xi(n), eta(kg), lglketa(Ntot2, kg)
   integer i, j
   double precision zsam(n), msam(n), jsam(n), sam(n)
-  double precision nu, phi, nsq, kappa
+  double precision nu, phi, omg, kappa
 
   call create_model (ifam)
   call create_spcor(icf,n)
@@ -380,9 +385,9 @@ subroutine bfsp_tr (weights, zcv, logbf, lglk1, lglk2, &
   do i = 1, kg
     nu = nulist(i)
     phi = philist(i)
-    nsq = nsqlist(i)
+    omg = omglist(i)
     kappa = kappalist(i)
-    call calc_cov (phi,nsq,dm,F,betQ0,&
+    call calc_cov (phi,omg,dm,F,betQ0,&
        kappa,n,p,T,TiF,FTF,Ups,ldh_Ups)
     do j = 1, Ntot1
       call rchkusr
@@ -394,11 +399,11 @@ subroutine bfsp_tr (weights, zcv, logbf, lglk1, lglk2, &
       elsewhere (itr == 1)
         msam = sam
         zsam = flink(msam,nu)
-        jsam = logilinkdz(zsam,nu)
+        jsam = loginvlinkdz(zsam,nu)
       elsewhere (itr == 2)
         zsam = transfw(sam,nu)
         msam = invlink(zsam,nu)
-        jsam = logitrwdz(zsam,nu)
+        jsam = loginvtrwdz(zsam,nu)
       end where
       lglk1(j,i) = logpdfzf(n,zsam,Ups,ldh_Ups,xi,lmxi,ssqdfsc,modeldfh) &
          + condymuf(ifam, n,y,l,msam,tsqval,respdfh) - sum(jsam)
@@ -413,11 +418,11 @@ subroutine bfsp_tr (weights, zcv, logbf, lglk1, lglk2, &
       elsewhere (itr == 1)
         msam = sam
         zsam = flink(msam,nu)
-        jsam = logilinkdz(zsam,nu)
+        jsam = loginvlinkdz(zsam,nu)
       elsewhere (itr == 2)
         zsam = transfw(sam,nu)
         msam = invlink(zsam,nu)
-        jsam = logitrwdz(zsam,nu)
+        jsam = loginvtrwdz(zsam,nu)
       end where
       lglk2(j,i) = logpdfzf(n,zsam,Ups,ldh_Ups,xi,lmxi,ssqdfsc,modeldfh) &
          + condymuf(ifam, n,y,l,msam,tsqval,respdfh) - sum(jsam)
